@@ -1,7 +1,7 @@
 use 5.14.0;
 
 package OpenGbg::Service::StyrOchStall::Stations;
-$OpenGbg::Service::StyrOchStall::Stations::VERSION = '0.1101';
+$OpenGbg::Service::StyrOchStall::Stations::VERSION = '0.1200';
 use XML::Rabbit;
 use Kavorka;
 
@@ -34,7 +34,7 @@ OpenGbg::Service::StyrOchStall::Stations - A list of Styr och Ställ stations
 
 =head1 SYNOPSIS
 
-    my $service OpenGbg->new->styr_och_stall;
+    my $service = OpenGbg->new->styr_och_stall;
     my $response = $service->get_bike_stations;
 
     printf 'Time: %s', $response->timestamp;
